==> haskell-rvar-0.3.0.2-122.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-JPr3ogZHIajHSgTYM8PKZ5
key:                  rvar-0.3.0.2-JPr3ogZHIajHSgTYM8PKZ5
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  990e6591663fee3ecbc2a188a74f51b7
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-JPr3ogZHIajHSgTYM8PKZ5
depends:
    MonadPrompt-1.0.0.5-45KZ6GehS5A3DH7BS5Bf5a base-4.18.2.1
    bytestring-0.11.5.3 mtl-2.3.1 random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rvar-0.3.0.2-123-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-C4y2Zxo4rw1CM4ByCjMXDn
key:                  rvar-0.3.0.2-C4y2Zxo4rw1CM4ByCjMXDn
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  38cada6183c92ddb8faed7f6497dc7d0
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-C4y2Zxo4rw1CM4ByCjMXDn
depends:
    MonadPrompt-1.0.0.5-45KZ6GehS5A3DH7BS5Bf5a base-4.18.2.1
    bytestring-0.11.5.3 mtl-2.3.1 random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
